import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:intl/intl.dart';

import '../../../core/models/account_head_model.dart';
import '../../../core/theme/button_theme.dart';
import '../../../core/theme/layout_theme.dart';
import '../../../core/values/colors.dart';
import '../../../core/values/strings.dart';
import '../../../data/enums/enums.dart';
import '../../../data/providers/db_provider.dart';
import '../controllers/account_head_controller.dart';
import '../widgets/account_head_section.dart';

class AccountHeadView extends GetView<AccountHeadController> {
  final AccountHeadController _accountHeadController =
      Get.find<AccountHeadController>();

  @override
  Widget build(BuildContext context) {
    return MainLayout(
        isDrawer: true,
        appbar: AppBar(title: Text('Account Heads')),
        body: Container(
          //height: MediaQuery.of(context).size.height * 0.4,
          decoration: BoxDecoration(),
          child: GetBuilder<AccountHeadController>(builder: (logic) {
            return FutureBuilder(
              future: MoneyLogsDatabase.instance.incomeExpenseAccountHeads(),
              builder: (
                BuildContext context,
                AsyncSnapshot<List<AccountHead>> snapshot,
              ) {
                if (snapshot.connectionState == ConnectionState.done) {
                  if (snapshot.hasError) {
                    return errorSection();
                  } else if (snapshot.data!.isEmpty) {
                    return noDataSection();
                  } else if (snapshot.hasData) {
                    // return Obx(() {
                    return AccountHeadSection(
                      accHead: snapshot,
                      canDelete: _accountHeadController.checkCanDelete,
                    );
                    // });
                  }
                }
                return const Center(child: CircularProgressIndicator());
              },
            );
          }),
        ),
        //TabBarView(children: [IncomeHeadView(), ExpenseHeadView()]);
        isFloatingButton: true,
        floatingActionButton: Column(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            FloatingActionButton(
              heroTag: "Income",
              backgroundColor: buttonGreen,
              child: const Icon(Icons.add),
              onPressed: () {
                addCategoryDialog(AccountHeadType.income.index);
              },
            ),
            SizedBox(height: 10),
            FloatingActionButton(
              heroTag: "Expense",
              backgroundColor: buttonRed,
              child: const Icon(Icons.add),
              onPressed: () {
                addCategoryDialog(AccountHeadType.expense.index);
              },
            ),
          ],
        ));
  }

  addCategoryDialog(int accountHeadType) {
    String myTitle = "";
    if (accountHeadType == 1) {
      myTitle = "New Income Head";
    } else {
      myTitle = "New Expense Head";
    }
    return Get.defaultDialog(
      title: myTitle,
      textConfirm: "Add",
      confirmTextColor: whiteE5,
      buttonColor: buttonGreen,
      textCancel: "Cancel",
      cancelTextColor: buttonRed,
      content: accountHeadName(),
      onConfirm: () async {
        if (_accountHeadController.accountHeadCtl.text.isEmpty) {
          Get.snackbar("Error", "Head can't be empty", colorText: buttonRed);
        } else {
          try {
            await MoneyLogsDatabase.instance.addAccountHead(
              AccountHead(
                name: _accountHeadController.accountHeadCtl.text,
                type: accountHeadType,
                createdBy: 1,
                createAt: DateFormat('dd-MM-yyyy').format(DateTime.now()),
              ),
            );
            _accountHeadController.accountHeadCtl.text = "";
            _accountHeadController.update();
            Get.back();
          } catch (e) {
            log(e.toString());
            Get.back();
            Get.snackbar(
              "Error",
              "Head name can't be same",
              colorText: buttonRed,
            );
          }
          _accountHeadController.accountHeadCtl.text = "";
          _accountHeadController.update();
        }
      },
    );
  }

  TextFormField accountHeadName() {
    return TextFormField(
      controller: _accountHeadController.accountHeadCtl,
      decoration: InputDecoration(hintText: "Head Title"),
    );
  }

  // DropdownButtonFormField<AccountHeadType> accountTypeDropdownButton() {
  //   final accountHeadType = [AccountHeadType.income, AccountHeadType.expense];
  //
  //   return DropdownButtonFormField<AccountHeadType>(
  //     hint: Text("Please select type"),
  //     items: accountHeadType
  //         .map(
  //           (e) => DropdownMenuItem(child: Text(e.name), value: e),
  //         )
  //         .toList(),
  //     onChanged: (value) {
  //       _accountHeadController.selectedACHeadType.value = value!.index;
  //     },
  //   );
  // }

  ListView noDataSection() {
    return ListView(children: [
      ...buildCheckBox(),
      Padding(
        padding: const EdgeInsets.all(18.0),
        child: SubmitButton(
          title: "Add Account Heads",
          onTap: () async {
            await _accountHeadController.addAcHeads();
          },
          buttonColor: buttonGreen,
        ),
      ),
    ]);
  }

  List<Obx> buildCheckBox() {
    return _accountHeadController.accountHeadList
        .map(
          (incomeHead) => Obx(() {
            return ListTile(
              title: Text(incomeHead.name!, style: TextStyles.normal16White),
              leading: Checkbox(
                value: incomeHead.add.value,
                onChanged: (value) {
                  incomeHead.add.value = value!;
                },
              ),
            );
          }),
        )
        .toList();
  }

  Center errorSection() {
    return Center(
      child: Text('Error occurred', style: const TextStyle(fontSize: 18)),
    );
  }
}
